@@ -60,11 +60,14 @@ class MediawikiImportController(ToolImportController):
 
 class MediawikiImporter(ToolImporter):
     target_app_ep_names = 'wiki'
-    source = 'Mediawiki'
     controller = MediawikiImportController
     tool_label = 'Wiki'
     tool_description = 'Import your mediawiki.'
 
+    @property
+    def source(self):
+        return config['site_name'] + ' Mediawiki'
+
     def import_tool(self, project, user, project_name=None, mount_point='wiki',
                     mount_label='Wiki', **kw):
         app = project.install_app(
